<?php

namespace Drupal\bitlink\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Configuration form for bitlink module.
 */
class BitlinkConfigForm extends ConfigFormBase {

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'bitlink_config_form';
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return ['bitlink.settings'];
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $bitlink_config = $this->config('bitlink.settings');

    $form['bitlink_settings'] = [
      '#type' => 'details',
      '#title' => t('Bitlink API settings'),
      '#open' => TRUE,
    ];

    $form['bitlink_settings']['api_base_url'] = [
      '#type' => 'textfield',
      '#title' => t('API Base URL'),
      '#default_value' => $bitlink_config->get('api_base_url'),
      '#description' => t('The Wallet Webservice Endpoint Base URL. Avoid trailing slash.'),
      '#required' => TRUE,
    ];

    $form['bitlink_settings']['username'] = [
      '#type' => 'textfield',
      '#title' => t('Username'),
      '#default_value' => $bitlink_config->get('username'),
      '#description' => t('Bitlink Username.'),
      '#required' => TRUE,
    ];

    $form['bitlink_settings']['password'] = [
      '#type' => 'password',
      '#title' => t('Password'),
      '#default_value' => $bitlink_config->get('password'),
      '#description' => t('Bitlink Password.'),
      '#required' => TRUE,
    ];

    $form['bitlink_settings']['oauth_clientid'] = [
      '#type' => 'textfield',
      '#title' => t('OAuth Client ID'),
      '#default_value' => $bitlink_config->get('oauth_clientid'),
      '#description' => t('Bitlink API OAuth Client ID.'),
      '#required' => TRUE,
    ];

    $form['bitlink_settings']['oauth_clientsecret'] = [
      '#type' => 'textfield',
      '#title' => t('OAuth Client Secret'),
      '#default_value' => $bitlink_config->get('oauth_clientsecret'),
      '#description' => t('Bitlink API OAuth Client Secret.'),
      '#required' => TRUE,
    ];

    $form['bitlink_settings']['group_guid'] = [
      '#type' => 'textfield',
      '#title' => t('Group GUID'),
      '#default_value' => $bitlink_config->get('group_guid'),
      '#description' => t('Bitlink API Group GUID. Leave this field empty to populate it from Bitlink API server.'),
    ];

    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function validateForm(array &$form, FormStateInterface $form_state) {

    parent::validateForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $bitlink_service = \Drupal::service('bitlink.api_service');
    $bitlink_config = $this->config('bitlink.settings');

    $bitlink_config
      ->set('api_base_url', $form_state->getValue('api_base_url'))
      ->set('username', $form_state->getValue('username'))
      ->set('password', $form_state->getValue('password'))
      ->set('oauth_clientid', $form_state->getValue('oauth_clientid'))
      ->set('oauth_clientsecret', $form_state->getValue('oauth_clientsecret'));

    if (empty($form_state->getValue('group_guid'))) {
      $form_data = [
        'api_base_url' => $form_state->getValue('api_base_url'),
        'username' => $form_state->getValue('username'),
        'password' => $form_state->getValue('password'),
        'oauth_clientid' => $form_state->getValue('oauth_clientid'),
        'oauth_clientsecret' => $form_state->getValue('oauth_clientsecret'),
      ];

      $response_data = $bitlink_service->getGroupsInfo($form_data);

      if (isset($response_data['groups']) && !empty($response_data['groups'])) {
        $bitlink_config->set('group_guid', $response_data['groups']['0']->guid);
      }
    }
    else {
      $bitlink_config->set('group_guid', $form_state->getValue('group_guid'));
    }

    $bitlink_config->save();

    parent::submitForm($form, $form_state);
  }

}
